# Data Object Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#description)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#guidelines-and-best-practices)
  * [How to Model Data Objects for Data Classification](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#how-to-model-data-objects-for-data-classification)
  * [How to Model Data Objects for CRUD on the Application Landscape](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#how-to-model-data-objects-for-crud-on-the-application-landscape)
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#antipatterns)
  * [Applicable Use Cases](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#applicable-use-cases)
  * [Insights from Data Object Fact Sheet](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#insights-from-data-object-fact-sheet)
  * [Related Information](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines?version=CLOUD#related-information)


Learn how to model data objects. This includes best practices and applicable use cases, and common antipatterns.
**Note**
These modeling guidelines are for the meta model v4. For meta model v3 guidelines, see [Modeling: Data Object](https://help.sap.com/docs/leanix/ea/data-object-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, you will find a best practice Data Object model to upload to your workspace.").
